#!/usr/bin/env python3

##########################
#     WRAPPER SCRIPT     #
#     DEALS WITH MISP    #
#     TO STIX            #
##########################


import argparse
import pyaml
import time
import sys
import os
import logging

from misp_stix_converter.servers import misp
from misp_stix_converter.converters import convert
from misp_stix_converter.converters import lint_roller

parser = argparse.ArgumentParser(description='Process some integers.')
inputg = parser.add_mutually_exclusive_group(required=True)

inputg.add_argument("-f", "--file", help="The MISP JSON file to convert")
inputg.add_argument("-i", "--eid", help="The MISP event ID to pull and convert")
inputg.add_argument("-t", "--tag", help="Download all of a single tag")

parser.add_argument('-o', '--outfile', help="The file to output to. Default is stdout.", default="stdout")
parser.add_argument("-c", "--config", help="Path to config file. Default is misp.login.")
parser.add_argument("-v", "--verbose", help="More output", default=False, action="store_true")
parser.add_argument("-l", "--logfile", help="Where to send the log to", default="converter.log")
parser.add_argument("--format", help="The output format [JSON/XML]. Default JSON.")
parser.add_argument("--stix-version", help="Set the STIX output version. Default 1.2.")

args = parser.parse_args()

log = logging.getLogger(__name__)
handler = logging.FileHandler(args.logfile)
formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')

handler.setFormatter(formatter)
log.addHandler(handler)
log.setLevel(logging.DEBUG if args.verbose else logging.INFO)

log.info("MISP<->STIX Converter")

# Set the config file
if args.config:
    configfile = args.config
else:
    configfile = os.path.expanduser("~/.misptostix/misp.login")

log.debug("Using config file at %s", configfile)

try:
    with open(configfile, "r") as f:
        CONFIG = pyaml.yaml.load(f)
except FileNotFoundError:
    print("Could not find config file {}".format(configfile))
    sys.exit(1)

if args.tag and not ("{}" in args.outfile):
    args.outfile += ".{}"

if args.format:
    args.format = args.format.lower()
    if args.format not in ["json", "xml"]:
        print("Only possible output formats are JSON and XML.")
        print("{} is not valid".format(args.format))
        sys.exit()
else:
    args.format = "json"

if (args.file):

    log.debug("Converting file at %s", args.file)

    # This is just a file conversion
    # Relatively quick and easy
    # Create a non-connected misp instance
    try:
        with open(args.file, "r") as f:
            jsondata = f.read()
        package = convert.MISPtoSTIX(jsondata)
    except FileNotFoundError:
        print("Could not open {}".format(args.file))
        sys.exit()

else:
    # Backwards compatability, if users haven't updated config
    if "SSL" not in CONFIG["MISP"]:
        print("Please update your config file using the misp.login.example to include SSL\n")
        time.sleep(1)
        CONFIG["MISP"]["SSL"] = False

    # This requires a connection to MISP
    # As we need to pull an event
    # Connect to MISP
    MISP = misp.MISP(CONFIG["MISP"]["URL"], CONFIG["MISP"]["KEY"], CONFIG["MISP"].get("SSL", True))

    if args.tag:
        log.debug("Converting all events tagged with %s", args.tag)
        package = MISP.pull(tags=[args.tag])
    else:
        log.debug("Converting event %s", args.eid)
        try:
            package = MISP.pull(args.eid)[0]
        except IndexError:
            log.fatal("Could not find event %s", args.eid)
            print("ERROR :: SEE LOG FILE")
            sys.exit(1)


def write_pkg(pkg, outfile):
    # Set the version
    log.debug("Writing to %s", outfile)
    log.debug("As stix v%s", args.stix_version)

    if args.stix_version:
        if args.stix_version == "1.1.1":
            objs = lint_roller.lintRoll(pkg)
            for i in objs:
                # Set the object's version
                if hasattr(i, "version"):
                    i.version = args.stix_version

        elif args.stix_version == "1.2":
            pass  # Is default
        else:
            print("INVALID STIX VERSION {}".format(args.stix_version))
            sys.exit()

    if args.format == "json":
        log.debug("In JSON format")
        # Output to JSON
        if outfile == "stdout":
            # Output to stdout
            print(pkg.to_json())
        else:
            # Output to file
            with open(outfile, "w") as f:
                f.write(pkg.to_json())
    else:
        log.debug("In XML format")
        # Output to XML
        if outfile == "stdout":
            # Output to stdout
            print(pkg.to_xml())
        else:
            # Output to file
            with open(outfile, "wb") as f:
                f.write(pkg.to_xml())

    log.debug("Written!")

if not args.tag:
    write_pkg(package, args.outfile)
else:
    for p in package:
        write_pkg(p, args.outfile.format(p.MISPID))



#!/usr/bin/env python3
import re
import cybox
import logging
import hashlib
import ast
from pymisp import mispevent
from misp_stix_converter.converters.lint_roller import lintRoll
from stix.core import STIXPackage


# Cybox cybox don't we all love cybox children
from cybox.objects import email_message_object, file_object, address_object, socket_address_object
from cybox.objects import domain_name_object, hostname_object, uri_object
from cybox.objects import mutex_object, whois_object
from cybox.objects import as_object, http_session_object
from cybox.objects import pipe_object, network_packet_object, win_registry_key_object
from cybox.objects import x509_certificate_object, win_executable_file_object, win_process_object


# Just a little containment file for STIX -> MISP conversion
ipre = re.compile("([0-9]{1,3}.){3}[0-9]{1,3}")
log = logging.getLogger("__main__")


def uniq(lst):
    return_list = []
    for elem in lst:
        if elem not in return_list:
            return_list.append(elem)
    return return_list


def ast_eval(node):
    try:
        node = ast.literal_eval(node)
        if isinstance(node, list):
            node = uniq(node)
        return node
    except ValueError:
        return str(node)
    except SyntaxError:
        return str(node)


def parseRelated(obj, mispEvent, pkg):
    """Dedicated to parse related object
    Support for first level "importRelated.related_objects"
    """

    for i in obj.related_object:
        type_ = type(i.properties)
        # Here comes the sun (and of course the fun) for related objects! (DB)
        if type_ == address_object.Address:
            buildAddressAttribute(i.properties, mispEvent, pkg)

        elif type_ == domain_name_object.DomainName:
            buildDomainNameAttribute(i.properties, mispEvent, pkg)

        elif type_ == hostname_object.Hostname:
            buildHostnameAttribute(i.properties, mispEvent, pkg)

        elif type_ == socket_address_object.SocketAddress:
            buildAddressAttribute(i.properties, mispEvent, pkg, True)

        elif type_ == uri_object.URI:
            buildURIAttribute(i.properties, mispEvent, pkg)

        elif type_ == file_object.File:
            buildFileAttribute(i.properties, mispEvent, pkg)

        elif type_ == email_message_object.EmailMessage:
            buildEmailMessageAttribute(i.properties, mispEvent, pkg)

    return mispEvent


def parseAttachment(obj, mispEvent, pkg):
    """
    Limited support for email attachments, just consider this a work in progress
    """

    for i in obj:
        # Assuming any email attached file is a... file!
        buildFileAttribute(i.properties, mispEvent, pkg)

    return mispEvent


def buildFileAttribute(obj, mispEvent, pkg, importRelated=False):
    """
    All you can get by a File object in a single method
    TODO: all possible attributes are not yet parsed
    """

    if obj.file_name:
        mispEvent.add_attribute('filename', ast_eval(str(obj.file_name)), comment=pkg.title or None)

    # Added support to file_extension
    # No MISP object available for file extension
    # I propose to use pattern-in-file. Suggestions are welcome! (DB)
    if obj.file_extension:
        mispEvent.add_attribute('pattern-in-file', ast_eval(str(obj.file_extension)), comment=pkg.title or None)

    if obj.size_in_bytes:
        mispEvent.add_attribute('size-in-bytes', ast_eval(str(obj.size_in_bytes)), comment=pkg.title or None)

    if obj.md5:
        # We actually have to check the length
        # An actual report had supposed md5s of length 31. Silly.
        if len(obj.md5) == 32:
            mispEvent.add_attribute('md5', ast_eval(str(obj.md5)), comment=pkg.title or None)

    if obj.sha1:
        if len(obj.sha1) == 40:
            mispEvent.add_attribute('sha1', ast_eval(str(obj.sha1)), comment=pkg.title or None)

    if obj.sha256:
        if len(obj.sha256) == 64:
            mispEvent.add_attribute('sha256', ast_eval(str(obj.sha256)), comment=pkg.title or None)

    # Added support for SHA512 (DB)
    if obj.sha512:
        if len(obj.sha512) == 128:
            mispEvent.add_attribute('sha512', ast_eval(str(obj.sha512)), comment=pkg.title or None)

    if importRelated and pkg.object_.related_objects:
        parseRelated(pkg.object_.related_objects, mispEvent, pkg)

    return mispEvent


def buildAddressAttribute(obj, mispEvent, pkg, importRelated=False):

    if obj.is_source:
        mispEvent.add_attribute('ip-src', ast_eval(str(obj.address_value)), comment=pkg.title or None)

    elif obj.is_destination:
        mispEvent.add_attribute('ip-dst', ast_eval(str(obj.address_value)), comment=pkg.title or None)
    else:
        # We don't know, first check if it's an IP range
        if hasattr(obj, "condition") and obj.condition:
            if obj.condition == "InclusiveBetween":
                # Ok, so it's a range. hm. Shall we add them seperately#comma#or together?
                mispEvent.add_attribute('ip-dst', ast_eval(str(obj.address_value[0])))
                mispEvent.add_attribute('ip-dst', ast_eval(str(obj.add_attribute[1])))
            elif obj.condition == "Equals":
                mispEvent.add_attribute('ip-dst', ast_eval(str(obj.address_value)), comment=pkg.title or None)
        else:
            # Don't have anything to go on
            mispEvent.add_attribute('ip-dst', ast_eval(str(obj.address_value)), comment=pkg.title or None)

    if importRelated and pkg.object_.related_objects:
        parseRelated(pkg.object_.related_objects, mispEvent, pkg)

    return mispEvent


def buildEmailMessageAttribute(obj, mispEvent, pkg, importRelated=False):
    if obj.header:
        # We have a header, can check for to/from etc etc
        if obj.header.from_:
            mispEvent.add_attribute('email-src',
                                    ast_eval(str(obj.header.from_.address_value)),
                                    comment=pkg.title or None)
        if obj.header.to:
            for mail in obj.header.to:
                mispEvent.add_attribute('email-dst', ast_eval(mail.address_value), comment=pkg.title or None)
        if obj.header.subject:
            mispEvent.add_attribute('email-subject', ast_eval(str(obj.header.subject)), comment=pkg.title or None)

    if obj.attachments and pkg.object_.related_objects:
        parseAttachment(pkg.object_.related_objects, mispEvent, pkg)

    elif importRelated and pkg.object_.related_objects:
        parseRelated(pkg.object_.related_objects, mispEvent, pkg)

    return mispEvent


def buildDomainNameAttribute(obj, mispEvent, pkg, importRelated=False):
    mispEvent.add_attribute('domain', ast_eval(str(obj.value)), comment=pkg.title or None)

    if importRelated and pkg.object_.related_objects:
        parseRelated(pkg.object_.related_objects, mispEvent, pkg)

    return mispEvent


def buildHostnameAttribute(obj, mispEvent, pkg, importRelated=False):
    mispEvent.add_attribute('hostname', ast_eval(str(obj.hostname_value)), comment=pkg.title or None)

    if importRelated and pkg.object_.related_objects:
        parseRelated(pkg.object_.related_objects, mispEvent, pkg)

    return mispEvent


def buildURIAttribute(obj, mispEvent, pkg, importRelated=False):
    mispEvent.add_attribute('url', ast_eval(str(obj.value)), comment=pkg.title or None)

    if importRelated and pkg.object_.related_objects:
        parseRelated(pkg.object_.related_objects, mispEvent, pkg)

    return mispEvent


def identifyHash(hsh):
    """
    What's that hash!?
    """

    possible_hashes = []

    hashes = [x for x in hashlib.algorithms_guaranteed]

    for h in hashes:
        if len(str(hsh)) == len(hashlib.new(h).hexdigest()):
            possible_hashes.append(h)
            possible_hashes.append("filename|{}".format(h))
    return possible_hashes


def open_stix(stix_thing):
    # Load the package
    if not hasattr(stix_thing, 'read'):
        stix_thing = open(stix_thing, "r")

    pkg = None
    try:
        pkg = STIXPackage().from_xml(stix_thing)
    except Exception:
        try:
            pkg = STIXPackage.from_json(stix_thing)
        except Exception:
            raise Exception("Could not load package!")
    return pkg


def buildEvent(pkg, **kwargs):
    log.info("Building Event...")
    if not pkg.stix_header:
        title = "STIX Import"
    else:
        if not pkg.stix_header.title:
            title = "STIX Import"
        else:
            title = pkg.stix_header.title
    log.info("Using title %s", title)

    log.debug("Seting up MISPEvent...")
    event = mispevent.MISPEvent()
    event.distribution = kwargs.get("distribution", 0)
    event.threat_level_id = kwargs.get("threat_level_id", 3)
    event.analysis = kwargs.get("analysis", 0)
    event.info = title

    if hasattr(pkg, "description"):
        log.debug("Found description %s", pkg.description)
        event.add_attribute("comment", pkg.description)

    log.debug("Beginning to Lint_roll...")
    ids = []
    to_process = []
    for obj in lintRoll(pkg):
        if isinstance(obj, cybox.core.observable.Observable):
            if obj.id_ not in ids:
                ids.append(obj.id_)
                to_process.append(obj)

    log.debug("Processing %s object...", len(to_process))
    for obj in to_process:
        log.debug("Working on %s...", obj)
        # This will find literally every object ever.
        event = buildAttribute(obj, event)

    # Now make sure we only have unique items
    log.debug("Making sure we only have Unique attributes...")
    uniqueAttributes = []
    uniqueAttribValues = []

    for attrib in event.attributes:
        if attrib.value not in uniqueAttribValues:
            uniqueAttributes.append(attrib)
            uniqueAttribValues.append(attrib.value)

    event.attributes = uniqueAttributes
    log.debug("Finished parsing attributes.")
    return event


def buildAttribute(pkg, mispEvent):
    try:
        # Check if the object is a cybox observable
        if isinstance(pkg, cybox.core.observable.Observable):
            if hasattr(pkg, "object_") and pkg.object_:

                obj = pkg.object_.properties

                # It's a proper object!
                type_ = type(obj)
                # Here comes the fun!
                if type_ == address_object.Address:
                    # Now script uses buildAddressAttribute (DB)
                    buildAddressAttribute(obj, mispEvent, pkg, True)

                elif type_ == domain_name_object.DomainName:
                    # Now script uses buildDomainNameAttribute (DB)
                    buildDomainNameAttribute(obj, mispEvent, pkg, True)

                elif type_ == hostname_object.Hostname:
                    # Now script uses buildHostnameAttribute
                    buildHostnameAttribute(obj, mispEvent, pkg, True)

                elif type_ == socket_address_object.SocketAddress:
                    if obj.ip_address:
                        buildAddressAttribute(obj.ip_address, mispEvent, pkg, True)
                    if obj.hostname:
                        buildHostnameAttribute(obj.hostname, mispEvent, pkg, True)

                elif type_ == uri_object.URI:
                    # Now script uses buildURIAttribute (DB)
                    buildURIAttribute(obj, mispEvent, pkg, True)

                elif type_ == file_object.File:
                    # Now script uses buildFileAttribute (DB)
                    buildFileAttribute(obj, mispEvent, pkg, True)

                elif type_ == email_message_object.EmailMessage:
                    # Now script uses buildEmailMessageAttribute (DB)
                    buildEmailMessageAttribute(obj, mispEvent, pkg, True)

                elif type_ == mutex_object.Mutex:
                    mispEvent.add_attribute('mutex', ast_eval(str(obj.name)), comment=pkg.title or None)
                elif type_ == whois_object.WhoisEntry:
                    pass
                elif type_ == win_registry_key_object.WinRegistryKey:
                    pass
                elif type_ == network_packet_object.NetworkPacket:
                    pass
                elif type_ == http_session_object.HTTPSession:
                    pass
                elif type_ == pipe_object.Pipe:
                    mispEvent.add_attribute('named pipe', ast_eval(str(obj.name)), comment=pkg.title or None)
                elif type_ == as_object.AS:
                    mispEvent.add_attribute('AS', ast_eval(str(obj.number)),
                                            comment=pkg.title or ast_eval(str(obj.name)) or None)
                elif type_ == win_executable_file_object.WinExecutableFile:
                    pass
                elif type_ == win_process_object.WinProcess:
                    pass
                elif type_ == x509_certificate_object.X509Certificate:
                    pass
                else:
                    log.debug("Type not syncing %s", type_)
            else:
                pass
        else:
            pass  # Other objects. TODO.
    except Exception as ex:
        log.error(ex)
        log.exception(ex, exc_info=True)

    return mispEvent



#!/usr/bin/env python3

# A decoupled converter for misp<->Stix

# Imports
# Sys imports
import logging
from tempfile import SpooledTemporaryFile
import json
import base64
import random
import sys
from pymisp.abstract import MISPEncode
from pymisp import mispevent
from lxml import etree

# Stix imports
from stix.core import STIXPackage
from stix.core import STIXHeader
from stix.indicator import Indicator

# Local imports
from misp_stix_converter.errors import STIXLoadError
from misp_stix_converter.converters import buildSTIXAttribute
from misp_stix_converter.converters import buildMISPAttribute

log = logging.getLogger("__main__")


def MISPtoSTIX(mispJSON):
    """
        Function to convert from a MISP JSON to a STIX stix

        :param mispJSON: A dict (json) containing a misp Event.
        :returns stix: A STIX stix with as much of the original
                          data as we could convert.
    """
    if isinstance(mispJSON, mispevent.MISPEvent):
        misp_event = mispJSON
    else:
        misp_event = mispevent.MISPEvent()
        misp_event.load(mispJSON)

    # We should now have a proper MISP JSON loaded.

    # Create a base stix
    stix = STIXPackage()
    try:
        stix.MISPID = mispJSON["Event"]["id"]
    except Exception:
        # We don't have an ID?
        # Generate a random number and use that
        stix.MISPID = random.randint(1, 9000)
    # it's being silly
    # backup the ID
    backupID = stix.MISPID

    # Create a header for the new stix
    stix.stix_header = STIXHeader()

    # Try to use the event title as the stix title
    stix.stix_header.title = misp_event.info

    # Go through each attribute and transfer what we can.
    for one_attrib in misp_event.attributes:
        # We're going to store our observables inside an indicator
        # One for each attribute because @iglocska said so
        # I swear STIX is gonna be the death of me.
        indicator = Indicator()

        # Build an attribute from the JSON. Is all nice.
        buildSTIXAttribute.buildAttribute(one_attrib, stix, indicator)

        stix.add_indicator(indicator)

    stix.MISPID = backupID

    return stix


def load_stix(stix):
    # Just save the pain and load it if the first character is a <
    log.debug("Loading STIX...")
    if sys.version_info < (3, 5):
        json_exception = ValueError
    else:
        json_exception = json.JSONDecodeError

    if isinstance(stix, STIXPackage):
        log.debug("Argument was already STIX package, ignoring.")
        # Oh cool we're ok
        # Who tried to load this? Honestly.
        return stix

    elif hasattr(stix, 'read'):
        log.debug("Argument has 'read' attribute, assuming file-like.")
        # It's a file!
        # But somehow, sometimes, reading it returns a bytes stream and the loader dies on python 3.4.
        # Luckily, STIXPackage.from_json (which is mixbox.Entity.from_json) will happily load a string.
        # So we're going to play dirty.
        data = stix.read()
        log.debug("Read file, type %s.", type(data))

        if isinstance(data, bytes):
            data = data.decode()
        try:
            log.debug("Attempting to load from JSON...")
            # Try loading from JSON
            stix_package = STIXPackage.from_json(data)
        except json_exception:
            log.debug("Attempting to load from XML...")
            # Ok then try loading from XML
            # Loop zoop
            # Read the STIX into an Etree
            stix.seek(0)
            stixXml = etree.parse(stix)

            # Remove any "marking" sections because the US-Cert is evil
            log.debug("Removing Marking elements...")
            for element in stixXml.findall(".//{http://data-marking.mitre.org/Marking-1}Marking"):
                element.getparent().remove(element)

            log.debug("Writing cleaned XML to Tempfile")
            f = SpooledTemporaryFile(max_size=10 * 1024)
            f.write(etree.tostring(stixXml))
            f.seek(0)

            try:
                log.debug("Attempting to read clean XML into STIX...")
                stix_package = STIXPackage.from_xml(f)
            except Exception as ex:
                # No joy. Quit.
                log.fatal("Could not :<")
                f.seek(0)
                with open("FAILED_STIX.xml", "wb") as g:
                    g.write(f.read())
                raise STIXLoadError("Could not load stix file. {}".format(ex))

        return stix_package

    elif isinstance(stix, str):
        # It's text, we'll need to use a temporary file

        # Create a temporary file to load from
        # Y'know I should probably give it a max size before jumping to disk
        # idk, 10MB? Sounds reasonable.
        f = SpooledTemporaryFile(max_size=10 * 1024)

        # O I have idea for sneak
        # Will be very sneak
        # Write the (probably) XML to file
        f.write(stix.encode("utf-8"))

        # Reset the file so we can read from it
        f.seek(0)

        # AHA SNEAK DIDN'T EXPECT RECURSION DID YOU
        return load_stix(f)


def STIXtoMISP(stix, mispAPI, **kwargs):
    """Function to convert from something stixxy ( as we have 3 possible representations )
    to something mispy. Specifically JSON. Because XML is satan.

    :param stix: Something stixxy.
    """

    log.info("Converting a package from STIX to MISP...")

    stixPackage = load_stix(stix)
    # Ok by now we should have a proper STIX object.
    log.debug("Package loaded")

    # We'll try to extract a filename
    filename = "STIX_File.xml"
    if isinstance(stix, str) and "\n" not in stix:
        # It's probably just a filename
        filename = stix
    elif hasattr(stix, "name"):
        # Steal this one!
        filename = stix.name
    elif hasattr(stixPackage, "stix_header"):
        # Well it has a header, maybe we can steal it
        if stixPackage.stix_header:
            if stixPackage.stix_header.title not in ["", None]:
                filename = stixPackage.stix_header.title + ".xml"

    log.debug("Using filename %s", filename)

    misp_event = buildMISPAttribute.buildEvent(stixPackage, **kwargs)

    log.debug("Encoding to b64...")
    b64Pkg = base64.b64encode(stixPackage.to_xml()).decode("utf-8")
    log.debug("Attaching original document...")
    misp_event.add_attribute(type="attachment", value=filename, data=b64Pkg)

    if misp_event.attributes:
        log.debug("Attributes exist. Pushing...")
        response = mispAPI.add_event(json.dumps(misp_event, cls=MISPEncode))
        if response.get('errors'):
            raise Exception("PACKAGE: {}\nERROR: {}".format(json.dumps(misp_event, cls=MISPEncode),
                                                            response.get('errors')))

        return response
    else:
        log.warning("No attributes found, ignoring.")



#!/usr/bin/env python3

##########################
#     WRAPPER SCRIPT     #
#     DEALS WITH STIX    #
#     TO MISP            #
##########################


import argparse
import logging
import pyaml
import time
import sys
import os

from misp_stix_converter.servers import misp
from misp_stix_converter.converters.buildMISPAttribute import open_stix

parser = argparse.ArgumentParser(description='Process some integers.')
parser.add_argument("-c", "--config", help="Path to config file. Default is misp.login.")
parser.add_argument("-v", "--verbose", help="Increase logging verbosity.", default=False, action="store_true")
parser.add_argument("file", help="The STIX file to push")

args = parser.parse_args()

# Set up a logger
log = logging.getLogger(__name__)
log.setLevel(logging.DEBUG if args.verbose else logging.INFO)
ch = logging.StreamHandler(sys.stdout)
ch.setLevel(logging.DEBUG if args.verbose else logging.INFO)
formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
ch.setFormatter(formatter)
log.addHandler(ch)

# Set the config file
if args.config:
    configfile = args.config
else:
    configfile = os.path.expanduser("~/.misptostix/misp.login")

try:
    with open(configfile, "r") as f:
        CONFIG = pyaml.yaml.load(f)
except FileNotFoundError:
    log.fatal("Could not find config file %s", configfile)
    sys.exit(1)

# Backwards compatability, if users haven't updated config
if "SSL" not in CONFIG["MISP"]:
    log.warning("Please update your config file using the misp.login.example to include SSL")
    time.sleep(1)
    CONFIG["MISP"]["SSL"] = False

# This is just a file conversion
# Relatively quick and easy
MISP = misp.MISP(CONFIG["MISP"]["URL"], CONFIG["MISP"]["KEY"], CONFIG["MISP"].get("SSL", True))

# Load the package
log.info("Opening STIX file %s", args.file)
pkg = open_stix(args.file)

# We'll use my nice little misp module
log.info("Pushing to MISP...")
MISP.push(pkg)
log.info("COMPLETE")
